@@ -132,7 +132,7 @@ class WorkerServer(BaseServer):
             queue=self.amqp_queue,
             exchange=self.amqp_exchange)
         yield self.chan.basic_consume(queue=self.amqp_queue,
-            no_ack=False,
+            no_ack=True,
             consumer_tag="awspider_consumer")
         self.queue = yield self.conn.queue("awspider_consumer")
         yield BaseServer.start(self)
@@ -218,22 +218,24 @@ class WorkerServer(BaseServer):
     def _executeJobCallback(self, data, job):
         self.jobs_complete += 1
         LOGGER.debug('Completed Jobs: %d / Queued Jobs: %d / Active Jobs: %d' % (self.jobs_complete, len(self.job_queue), len(self.active_jobs)))
-        if job.has_key('delivery_tag'):
-            d = self.chan.basic_ack(delivery_tag=job['delivery_tag'])
-            d.addCallback(self._basicAckCallback)
-            d.addErrback(self.basicAckErrback)
+        # FIXME basic_ack giving error "txamqp.client.Closed: Method(name=close, id=60) (503, 'COMMAND_INVALID - unknown delivery tag 15421', 60, 80) content = None"
+        # if job.has_key('delivery_tag'):
+        #             d = self.chan.basic_ack(delivery_tag=job['delivery_tag'])
+        #             d.addCallback(self._basicAckCallback)
+        #             d.addErrback(self.basicAckErrback)
         
     def workerErrback(self, error, function_name='Worker', delivery_tag=None):
         LOGGER.error('%s Error: %s' % (function_name, str(error)))
         LOGGER.debug('Queued Jobs: %d / Active Jobs: %d' % (len(self.job_queue), len(self.active_jobs)))
         LOGGER.debug('Active Jobs List: %s' % repr(self.active_jobs))
         self.pending_dequeue = False
-        if delivery_tag:
-            d = self.chan.basic_ack(delivery_tag=delivery_tag)
-            d.addCallback(self._basicAckCallback)
-            d.addErrback(self.basicAckErrback)
-        else:
-            return error
+        # FIXME basic_ack giving error "txamqp.client.Closed: Method(name=close, id=60) (503, 'COMMAND_INVALID - unknown delivery tag 15421', 60, 80) content = None"
+        # if delivery_tag:
+        #             d = self.chan.basic_ack(delivery_tag=delivery_tag)
+        #             d.addCallback(self._basicAckCallback)
+        #             d.addErrback(self.basicAckErrback)
+        #         else:
+        return error
         
     def _basicAckCallback(self, data):
         return
